#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2015, CERN
# This software is distributed under the terms of the GNU General Public
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".
# In applying this license, CERN does not waive the privileges and immunities
# granted to it by virtue of its status as Intergovernmental Organization
# or submit itself to any jurisdiction.

import tornado.web
import json
import base64
import logging

from tornado.testing import AsyncHTTPTestCase
from tornado.testing import get_unused_port
from timeout_decorator import timeout

from apiato.api.api import *

# class ClusterTest(AsyncHTTPTestCase):

#     """Class to test instances endpoint"""
#     authentication = "basic " + base64.b64encode(config.get('api','user') + ":" + config.get('api','pass'))

#     def get_app(self):
#         return tornado.web.Application(handlers, debug=True)

#     @timeout(5)
#     def test_get_volume_by_instance_name(self):

#         """test getting a volume by name"""

#         # Check the data for the given cluster
#         print "test_volume_metadata"
#         response = self.fetch("/api/v1/volume/apiato01")
#         self.assertEquals(response.code, 200)
#         data = json.loads(response.body)["response"]
#         self.assertEquals(len(data), 2)



#     @timeout(5)
#     def test_create_delete_volume(self):

#         """test for create and delete a volume with the right data"""

#         cluster = """{"instance_id": 3, "type_id": "2", "server": "NAS-server", "mounting_path": "/MNT/data01", "attributes": [{ "test": "testvalue"}, {"test01" : "test01value" }], "file_mode": "0755", "owner": "TSM", "group": "ownergroup", "mount_options": "rw,bg,hard"}"""
#         print "test_create_delete_volume"

#         # Insert the volume
#         response = self.fetch("/api/v1/volume/apiato03", method='POST', headers={'Authorization': self.authentication}, body=cluster)
#         self.assertEquals(response.code, 201)

#         # Check for the new volume
#         response = self.fetch("/api/v1/volume/apiato03")
#         self.assertEquals(response.code, 200)
#         data = json.loads(response.body)["response"]
#         self.assertEquals(len(data), 1)


#         # Delete the created instance
#         response = self.fetch("/api/v1/volume/" + str(data[0]["id"]) , method='DELETE', headers={'Authorization': self.authentication})
#         self.assertEquals(response.code, 204)

#         # Check again, the metadata should be empty
#         response = self.fetch("/api/v1/volume/apiato03")
#         self.assertEquals(response.code, 404)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2015, CERN
# This software is distributed under the terms of the GNU General Public
# Licence version 3 (GPL Version 3), copied verbatim in the file "LICENSE".
# In applying this license, CERN does not waive the privileges and immunities
# granted to it by virtue of its status as Intergovernmental Organization
# or submit itself to any jurisdiction.


#Functional alias module

import logging
import json
import requests
import tornado.web
import tornado.escape
from apiato.api.base import *
from apiato.config import config

class Type(tornado.web.RequestHandler):
    """
    This is the handler of **/<class>/types** endpoint.

    Things that are given for the development of this endpoint:

    * We request indirectly a `Postgres <https://www.postgresql.org/>`_ database through `PostgREST <http://postgrest.com/>`_ which returns a response in JSON format
    * The database's table that is used for this endpoint is called *host* and provides information for the functional alias association with an instance.
    * The columns of this table are like that:

    +----+--------+-------------+
    | id |  type  | description |
    +====+========+=============+
    | 42 | mysql  | MySQL Type  |
    +----+--------+-------------+

        * The *id* field is the type id, referenced by other resources
        * The *type* in this example is the type of an instance
        * The *description* is an optional field to include a short description

    The request methods implemented for this endpoint are:

    * :func:`get`

    """

    instance_url = config.get('postgrest', 'instance_type_url')
    volume_url = config.get('postgrest', 'volume_type_url')
    cluster_url = config.get('postgrest', 'cluster_type_url')

    def get(self, **args):
        """
        The *GET* method returns the list of types of the selected resource class.
        (No any special headers for this request)

        :param class: the class of the resource (instance/cluster/volume)
        :type class: str
        :rtype: json -- the response of the request
        :raises: HTTPError - when the requested name does not exist or if there is an internal 
        error or if the response is empty
        """

        class_n = args.get('class')
        type_n = args.get('type')
        logging.info('Requested ' + str(class_n) + ' ' + str(type_n))
        
        try:
            url = config.get('postgrest', '{}_{}_url'.format(str(class_n), str(type_n)))
        except:
            logging.error("Trying to get types of unknown class: " + str(class_n) + ' ' + str(type_n))
            raise tornado.web.HTTPError(NOT_FOUND)
        logging.info('URL==' + url)

        if url:
            response = requests.get(url)
            data = response.json()
            if response.ok and data:
                logging.debug("response: " + json.dumps(data))
                self.write({'response' : data})
                self.set_status(OK)
            else:
                logging.error("Error fetching types for class '" + str(class_n) + "': " + response.text)
                raise tornado.web.HTTPError(response.status_code)
        else:
            logging.warning("Not url configured for: " + str(class_n))
            raise tornado.web.HTTPError(NOT_FOUND)
